@@ -14,7 +14,7 @@ import (
 
 const (
 	// DefaultKernelVersion is the default Linux kernel version.
-	DefaultKernelVersion = "6.12.62-talos"
+	DefaultKernelVersion = "6.18.1-talos"
 
 	// KernelParamConfig is the kernel parameter name for specifying the URL.
 	// to the config.
@@ -87,6 +87,9 @@ const (
 	// KernelParamDashboardDisabled is the kernel parameter name for disabling the dashboard.
 	KernelParamDashboardDisabled = "talos.dashboard.disabled"
 
+	// KernelParamDashboardConsole is the kernel parameter name for specifying the dashboard console.
+	KernelParamDashboardConsole = "talos.dashboard.console"
+
 	// KernelParamEnvironment is the kernel parameter name for passing process environment.
 	KernelParamEnvironment = "talos.environment"
 
@@ -159,6 +162,10 @@ const (
 	// This param is injected by Equinix Metal and depends on the device ID and datacenter.
 	KernelParamEquinixMetalEvents = "em.events_url"
 
+	// KernelParamEnforceModuleSigVerify is the kernel parameter name to specify module signature verification enforcement.
+	// see https://github.com/siderolabs/talos/issues/11989
+	KernelParamEnforceModuleSigVerify = "module.sig_enforce"
+
 	// NewRoot is the path where the switchroot target is mounted.
 	NewRoot = "/root"
 
@@ -394,7 +401,7 @@ const (
 
 	// DefaultKubernetesVersion is the default target version of the control plane.
 	// renovate: datasource=github-releases depName=kubernetes/kubernetes
-	DefaultKubernetesVersion = "1.34.1"
+	DefaultKubernetesVersion = "1.35.0"
 
 	// SupportedKubernetesVersions is the number of Kubernetes versions supported by Talos starting from DefaultKubernesVersion going backwards.
 	SupportedKubernetesVersions = 6
@@ -422,7 +429,7 @@ const (
 
 	// DefaultCoreDNSVersion is the default version for the CoreDNS.
 	// renovate: datasource=docker depName=registry.k8s.io/coredns/coredns
-	DefaultCoreDNSVersion = "v1.12.4"
+	DefaultCoreDNSVersion = "v1.13.2"
 
 	// LabelNodeRoleControlPlane is the node label required by a control plane node.
 	LabelNodeRoleControlPlane = "node-role.kubernetes.io/control-plane"
@@ -455,8 +462,8 @@ const (
 	KubeletSystemReservedEphemeralStorage = "256Mi"
 
 	// DefaultEtcdVersion is the default target version of etcd.
-	// renovate: datasource=github-releases depName=etcd-io/etcd
-	DefaultEtcdVersion = "v3.6.5"
+	// renovate: datasource=docker depName=registry.k8s.io/etcd
+	DefaultEtcdVersion = "v3.6.7"
 
 	// EtcdRootTalosKey is the root etcd key for Talos-specific storage.
 	EtcdRootTalosKey = "talos:v1"
@@ -471,7 +478,7 @@ const (
 	EtcdTalosServiceAccountCRDControllerMutex = EtcdRootTalosKey + ":serviceAccountCRDController"
 
 	// EtcdImage is the reposistory for the etcd image.
-	EtcdImage = "gcr.io/etcd-development/etcd"
+	EtcdImage = "registry.k8s.io/etcd"
 
 	// EtcdPKIPath is the path to the etcd PKI directory.
 	EtcdPKIPath = "/system/secrets/etcd"
@@ -497,6 +504,9 @@ const (
 	// ConfigFilename is the filename of the saved config in STATE partition.
 	ConfigFilename = "config.yaml"
 
+	// EmbeddedConfigDirectory is the path to the embedded config is placed inside rootfs.
+	EmbeddedConfigDirectory = "/usr/local/etc/talos/"
+
 	// ConfigTryTimeout is the timeout of the config apply in try mode.
 	ConfigTryTimeout = time.Minute
 
@@ -551,7 +561,7 @@ const (
 	TrustdUserID = 51
 
 	// DefaultContainerdVersion is the default container runtime version.
-	DefaultContainerdVersion = "2.1.5"
+	DefaultContainerdVersion = "2.1.6"
 
 	// RuncVersion is the runc version.
 	RuncVersion = "1.3.4"
@@ -571,8 +581,11 @@ const (
 	// CRIContainerdConfig is the path to the config for the containerd instance that provides the CRI.
 	CRIContainerdConfig = "/etc/cri/containerd.toml"
 
-	// CRIConfdPath is the path to the directory providing parts of CRI plugin configuration.
-	CRIConfdPath = "/etc/cri/conf.d"
+	// EtcCRIConfdPath is the path to the directory providing parts of CRI plugin configuration.
+	EtcCRIConfdPath = "/etc/cri/conf.d"
+
+	// CRIConfdPath is the path to the subdirectory providing parts of CRI plugin configuration.
+	CRIConfdPath = "cri/conf.d"
 
 	// CRIConfig is the path to the CRI merged configuration file relative to /etc.
 	CRIConfig = "cri/conf.d/cri.toml"
@@ -589,6 +602,9 @@ const (
 	// TalosConfigEnvVar is the environment variable for setting the Talos configuration file path.
 	TalosConfigEnvVar = "TALOSCONFIG"
 
+	// TalosHomeEnvVar is the environment variable for setting the Talos state directory file path.
+	TalosHomeEnvVar = "TALOS_HOME"
+
 	// APISocketPath is the path to file socket of apid.
 	APISocketPath = SystemRunPath + "/apid/apid.sock"
 
@@ -715,6 +731,10 @@ const (
 	// UKIPCR is the PCR number where systemd-stub measures the UKI.
 	UKIPCR = 11
 
+	// SecureBootStatePCR is the PCR number where the secure boot state and the signature are measured.
+	// PCR 7 changes when UEFI SecureBoot mode is enabled/disabled, or firmware certificates (PK, KEK, db, dbx, …) are updated.
+	SecureBootStatePCR = 7
+
 	// DefaultCertificateValidityDuration is the default duration for a certificate.
 	DefaultCertificateValidityDuration = x509.DefaultCertificateValidityDuration
 
@@ -1108,7 +1128,7 @@ const (
 	DBusClientSocketLabel = "system_u:object_r:dbus_client_socket_t:s0"
 
 	// GoVersion is the version of Go compiler this release was built with.
-	GoVersion = "go1.24.11"
+	GoVersion = "go1.25.5"
 
 	// KubernetesTalosAPIServiceName is the name of the Kubernetes service to access Talos API.
 	KubernetesTalosAPIServiceName = "talos"
@@ -1220,15 +1240,15 @@ const (
 	// DefaultNfTablesTableName is the default name of the nftables table created by Talos.
 	DefaultNfTablesTableName = "talos"
 
+	// SystemResolvedPath is the path to the resolved dir.
+	SystemResolvedPath = SystemPath + "/resolved"
+
 	// PodResolvConfPath is the path to the pod resolv.conf file.
-	PodResolvConfPath = "/system/resolved/resolv.conf"
+	PodResolvConfPath = SystemResolvedPath + "/resolv.conf"
 
 	// SyslogListenSocketPath is the path to the syslog socket.
 	SyslogListenSocketPath = "/dev/log"
 
-	// MinimumGOAMD64Level is the minimum x86_64 microarchitecture level required by Talos.
-	MinimumGOAMD64Level = 2
-
 	// ConsoleLogErrorSuppressThreshold is the threshold for suppressing console log errors.
 	ConsoleLogErrorSuppressThreshold = 4
 
@@ -1258,6 +1278,9 @@ const (
 	// UserVolumeMountPoint is the path to the volume mount point for the user volumes.
 	UserVolumeMountPoint = "/var/mnt"
 
+	// LogMountPoint is the path to the logs mount point, and ID of the logs volume.
+	LogMountPoint = "/var/log"
+
 	// UserVolumePrefix is the prefix for the user volumes.
 	UserVolumePrefix = "u-"
 
@@ -1295,6 +1318,23 @@ const (
 
 	// ContainerMarkerFilePath is the path to the file added to container builds of Talos for platform detection.
 	ContainerMarkerFilePath = "/usr/etc/in-container"
+
+	// DefaultOOMTriggerExpression is the default CEL expression used to determine whether to trigger OOM.
+	DefaultOOMTriggerExpression = `memory_full_avg10 > 12.0 && d_memory_full_avg10 > 0.0 && time_since_trigger > duration("500ms")`
+
+	// DefaultOOMCgroupRankingExpression is the default CEL expression used to rank cgroups for OOM killer.
+	DefaultOOMCgroupRankingExpression = `memory_max.hasValue() ? 0.0 :
+		{Besteffort: 1.0, Burstable: 0.5, Guaranteed: 0.0, Podruntime: 0.0, System: 0.0}[class] *
+		   double(memory_current.orValue(0u))`
+
+	// SDStubCmdlineExtraOEMVar is the name of the SMBIOS OEM variable that can be used to pass extra kernel command line parameters to systemd-stub.
+	SDStubCmdlineExtraOEMVar = "io.systemd.stub.kernel-cmdline-extra"
+
+	// LogRotateThreshold is the size (in bytes), upon exceeding which the log file should be rotated.
+	LogRotateThreshold = 5 * 1024 * 1024
+
+	// LogFlushPeriod is the period for flushing in-memory log buffers to the filesystem.
+	LogFlushPeriod = 15 * time.Second
 )
 
 // See https://linux.die.net/man/3/klogctl
